function [out, nnet]=evalNN(n,ep,subdat,subdat_test,j,ra,numofinputs,numofoutputs,numofimages,numoftestimages)

%EVALNN  Gives the decision vector for the nth subset of the jth subband. It uses a 2-levels
%        NN with tan-sigmoid at the first level and linear at the second one.
%	 Initialization function is Nguyen-Widrow and update function is Levenberg-Marquard.
%	
%INPUT
%       n: the current iteration through the images: n={1...NN}
%	ep: the number of epochs
%	subdat: the training data (contains training and testing data, but only training data are used)
%	subdat_test: the testing data (contains training and testing data, but only testing data are used)
%	j: the subband index. it indexes subdat
%	ra: the amplitude of the data (max-min). Used by the init procedure (Nguyen-Widrow algorithm)
%	numofinputs: the dimension of the input, it is the size of the feature set
%	numofoutputs: the dimension of the ouput, it is the size of the class set
%	numofimages: the total number of images
%	numoftestimages: the number of images using for testing.
%
%OUTPUT
%	out:the decisions regarding the nth subset of the image set.
%
%Note:  We will think a decision to be a discrete probability distibution, 
%	the max of this distribution giving the final decision.
%	The problem is that a neural net doesn't have any notion of probability. 
%	The 'one hot' target should tend to give results 
%	close to satisfy the probability axioms, but it only 'tends'
%	The fact is that the decision vector is not normal
%	and is in |R^classes instead of P^classes
%	The results can be normalized by the function classifier/makeY1()
%

numoftrainimages=numofimages - numoftestimages;
numofpasses=numoftestimages/numofoutputs;% == numofimagesperclass/NN
numofimagesperclass=numofimages/numofoutputs;
    traindat=[];
    testdat=[];
    for f=1:numofoutputs
        oi=zeros(1,numofimages);
        abc=[(f-1)*numofimagesperclass+1:f*numofimagesperclass];
        oi(abc)=1;					%oi index the images of a particular class
        ti=[(n-1)*numofpasses+1:n*numofpasses]+(f-1)*numofimagesperclass;%mask numofpasses of the images indexed by oi
        oi(ti)=0;
        tr=find(oi==1);
        testdat=[testdat,subdat_test{j}(:,ti)];%[R]	% testdat is a set of
        						%  (1/n)x#[images/class]
       							% =#[images/class]-#traindat
        
        traindat=[traindat,subdat{j}(:,tr)];	% traindat is a set of
       				  		% #[images/class]x(1-1/n) feature vector
        			 		% hence here it is 40x10
    end
    
    % traindat and testdat has been concat 10 times: we have ten differents
    % splits of the original set of images subdat{j} 
    
    %newff modifies rand('state')
    nnet = newff(ra,[numofinputs numofoutputs],{'tansig' 'purelin'});
    % net{n} is a feed-forward NN with 2 layers. The 1st layer has a size
    % equals to #features, and 2nd layer has a size of #classes.
    %Though, net{n}: vectorOfFeature ---> probabilityVectorOfClass
    
    labels=ceil([1:numoftrainimages]/(numoftrainimages/numofoutputs)); 	%class label for traindat
    targets=zeros(numofoutputs,numoftrainimages);		%<#classx#traindat>  
    
    for m=1:numofoutputs
        ind=find(labels==m);
        targets(m,ind)=1;
    end
    
    %the target is now to attribute the right class to each image
    %i.e.: for an image with probability vector P[#class]:
    %				if the image is of class i target is: P[i]=1 else P[i]=0

    nnet.trainParam.epochs = ep;
     %train does NOT modify rand('state')
    nnet = train(nnet,traindat,targets);
    
    %sim does NOT modify rand('state')
    out = sim(nnet,testdat);
