function runNN(training_file, folder,NN,offset,NNep,shuf,evalNN_state)

%RUNNN: organize the NN computations for each subbands 
%	(setting the good parameters, organizing the input, structuring the results, storing them)
%
%INPUT
%     training_file:  The feature file to be used for training. If <training_file>_test.mat doesn't exists,
%		      it is USED FOR TESTING too.%
%     folder:  this is the location where the decision vectors from the
%         the classifier will be stored.
%     NN: 	      The number of NN per subband
%     offset:         Should be 0. just in case somebody use a weirde indexing 
%     NNep:           The number of iterations used to train the neural networks.
%     shuf:	      The shuffling matrix used to re-order the images inside the classes: 
%				size=<number of classes>x<number of images per class>
%		      		NOT OPTIONAL, even if not shuffled (use non-shuffled matrix) 
%     evalNN_state    [optional]   Tells the random generator which rand. state to use for each NN (same state for each NN)
%     
%OUTPUT
%	This function writes out one file per subband (subband<n>.mat) 
%	containing the output of the neuralnet for each image and the neural net itself
%       the output of the NN for each image is a classification decision based on 
%	the knowledge of a number of features (it may not be all the features 
%	if several feature set are used) for a given subband
%        
%
%If this function is directly called, make sure to record the state of the random generator to ensure reproducibility
%
%
% the [R] tag refers to lines specific to the separation of training/testing data 
% in two different files ('R' stands originally for rotation )
% to use 2 different files for training/testing, for each feature set xxxxxx.mat copy a modified feature set xxxxxx_test.mat
% the modified feature set must have the same properties has the original, i.e. data must have the same dimensions. Thus,
% it is ok to obtain xxxxxx_test.mat from rotation/shifting/[any transformation which takes an image and output an image] 
% of the original dataset used to xxxxxx.mat; but it is NOT ok to modify the #classes/#imgperclass/featuretype
% 								<=> don't modify the structure/meaning of data!


%define more explicit names for the data files
testing_file=regexprep(training_file,'.mat','_test.mat');	%[R]
data_test=[];					%[R]
load(training_file);
disp(['Training file:  ',training_file])
data_train=data;
if exist(testing_file,'file')==2		%[R]
	load(testing_file);			%[R]
	data_test=data;				%[R]
disp(['Testing file:  ',testing_file])		%[R]
else						%[R]
	data_test=data_train;			%[R]
end						%[R]
data=data_train;
clear data_train;
%we have data=data_train
%we will refer to data when the operation deals with the dimensions,
%which is the same for data_test and data_train, or deals with the training set
%
foo=mkdir(folder);

warning off MATLAB:nearlySingularMatrix;
numofclasses=length(data);				
numofsubbands=size(data{1},1)				
numofimagesperclass=size(data{1},2)			
numofimages=numofimagesperclass*numofclasses;		
numoffeats=length(data{1}{1});					
numoftestimages=numofimages/NN;% assume NN divide numofimages
numoftrainimages=numofimages -numoftestimages;


	for cls=1:numofclasses
		for iter=1:numofimagesperclass
			for sbd=1:numofsubbands
				shuf_data{1,cls}{sbd,shuf(cls,iter)}=data{1,cls}{sbd,iter};
                      		shuf_data_test{1,cls}{sbd,shuf(cls,iter)}=data_test{1,cls}{sbd,iter};%[R]
			end
		end
	end
	data=shuf_data;
	data_test=shuf_data_test;%[R]
	%------------------------------------------------------
for j=1:numofsubbands
    onesub=[];
    onesub_test=[];%[R]
    for i=1:numofclasses
        temp=data{i}(j,:);
	temp_test=data_test{i}(j,:);%[R]
        for k=1:numofimages/numofclasses
            onesub=[onesub;temp{k}];
            onesub_test=[onesub_test;temp_test{k}];%[R]
	end
    end
    subdat{j}=double(onesub');
    subdat_test{j}=double(onesub_test');%[R]
    %subdat{j} should now be a big fat <numoffeats x numofimages>double matrix
    %which means that subdat{j} has for column the features vector of each image

	%[?] in runNN.m: why do we compute ra here, we can compute it in evalNN to increase readability (less arguments passed)

	mx_train=double(max(subdat{j}'));%the max over all the images for each feature
							   %hence it is a <1xnumoffeats>double vector
	mi_train=double(min(subdat{j}'));%same thing for the min:	1xnumoffeats>double vector
%<---[R]
	mx_test=double(max(subdat{j}'));%the max over all the images for each feature
                                                   %hence it is a <1xnumoffeats>double vector
	mi_test=double(min(subdat{j}'));%same thing for the min:       1xnumoffeats>double vector

	ra=[min(mi_test,mi_train);max(mx_test,mx_train)]';%<numoffeatures x 2>double : 
						  %first the global min between training and testing data 
						  %then the global max
	minmax_train=[mi_train',mx_train'];%|
	minmax_test=[mi_test',mx_test'];   %|--> those 2 new variables are not used, just saved for the book-keeping
%[R]--->
	Y=[];
	if isempty(evalNN_state)==0
		rand('state',evalNN_state);
	end
	evalNN_state=rand('state');
	for n=1:NN
	
	%evalNN modifies rand('state')
	%[R] (the signature of evalNN has changed)
  	  [Y(:,(n-1)*numoftestimages+1:n*numoftestimages), net{n} ]= evalNN(n,NNep,subdat,subdat_test,j,ra,numoffeats,numofclasses,numofimages,numoftestimages);
   	 %clear net;
	end

	labelAbase=ceil([1:numoftestimages]/(numofimagesperclass/NN));%[ 1...(#imperclass/NN)...1 , 2...2 , ... , numofclasses (#imperclass/NN)]
	labelA=[];
	for k=1:NN
		labelA=[labelA,labelAbase];
	end
	save([folder,'/subband',num2str((j+offset)),'.mat'],'Y','labelA','minmax_train','minmax_test','ra','net');
end
