function weights=getWeights(DATA, numOfClass, labels, conf, epToQuit, margin, displayProgress)

%---------------------------------------------------------------------------------------------
%GETWEIGHTS: Open-Form weight training algorithm
%
%---------------------------------------------------------------------------------------------
%INPUT
% 	DATA:  This is the data for the weights to be trained on.  Arranged so that each
%     		column is an image and each numOfClass rows is a probability vector.
% 	numOfClass:  This is the number of classes in the training set.
% 	labels:  These are the actual class labels for the training data.  The
%     		length of labels will match the number of columns in DATA
%	conf:  parameter used in shifting weights.  usually set to 0.
% 	epToQuit:  how many epochs will you run before you quit shifting the weights
% 	margin:  factor used in shifting weights... ie boost (w=w*(1+margin))
%     		penalty(w=w*(1-margin))
% 	displayProgress:  set this to 1 for a line output display of progress.  0 to supress
%
%OUPTUT
%	weights: the weight vector used for the MR classification
%
%---------------------------------------------------------------------------------------------
%NOTE: This function USES THE RANDOM GENERATOR for the initialization.
%
%---------------------------------------------------------------------------------------------


initW=cell(1,3);
bestW=cell(1,3);
score=zeros(1,3);

lengthOfW=size(DATA,1)/numOfClass;
lengthOfW
%Initialize Weights
%first, initialize to probabilities.
for i=1:lengthOfW
    temp=DATA( (i-1)*numOfClass+1 : i*numOfClass,:);
    [y,index]=max(temp);
    initW{1}(i)=length(find((index-labels)==0))/size(DATA,2);
end
initW{1}=initW{1}/sum(initW{1});
%finished with first initialization.

%do initialization where no decomp is highly weighted.
highProb=.8;
initW{2}(1)=highProb;
for i=2:lengthOfW
    initW{2}(i)=(1-highProb)/(lengthOfW-1);
end
%done with second initialization

%do init of random weights
initW{3}=rand(1,lengthOfW);
sumofinit=sum(initW{3}(:));
initW{3}=initW{3}/sumofinit;
%done with random weight init

score(1)=evalACC(DATA,numOfClass,labels,initW{1},0);
bestW{1}=initW{1};

score(2)=evalACC(DATA,numOfClass,labels,initW{2},0);
bestW{2}=initW{2};

score(3)=evalACC(DATA,numOfClass,labels,initW{3},0);
bestW{3}=initW{3};

for k=1:3
    counter=0;
    while (counter<epToQuit)
        for i=1:size(DATA,2) %for each image
            iscor=evalACC(DATA(:,i),numOfClass,labels(i),initW{k},conf);
            if (~iscor)
                for j=1:lengthOfW
                    temp=DATA( (j-1)*numOfClass+1 : j*numOfClass,i);
                    [y,index]=max(temp);
                    if (index==labels(i))
                        initW{k}(j)=initW{k}(j)*(1+margin);
                    else
                        initW{k}(j)=initW{k}(j)*(1-margin);
                    end
                    initW{k}=initW{k}/sum(initW{k});
                end
            end
        end
        newscore=evalACC(DATA,numOfClass,labels,initW{k},0);
        if (newscore>score(k))
            score(k)=newscore;
            bestW{k}=initW{k};
            counter=0;
        else
            counter=counter+1;
        end
        if displayProgress
            fprintf('Weight Vector: %d, Newscore: %f, Cycles Since Improvement: %d\n',k,newscore,counter);
        end
    end
end

[y,index]=max(score);
weights=bestW{index(1)};
