function [ACC,overall,confusion]=runALL2(alldat,feat,numOfClass, IM_PER_CLASS,...
							labels, conf, epToQuit, margin, displayProgress,NN,SUBBAND,JOB_FOLDER)

%RUNALL2: Performs a 10-fold cross validation
%
%INPUT
%	alldat: 	The decision vector for each subband of each image
%	feat: 		An abbreaviation describing the features used.
%			only used to name the output file to avoid misundurstanding
%	numOfClass:	The number of different classes
%	IM_PER_CLASS:   The number of images per class
%	labels:		It indexes alldat, it gives the real class number of each image
%			(necessary to compute the accuracy)
%	conf:		Possibility to help or cripple the classifier: set to 0, so we are neutral.
%	epToQuit:	Number of iterations without accuracy enhancement before stopping the algorithm
%	margin:		The step used to correct the weights.
%	displayProgress:Display the iterations or not: 0 1 or 2 
%			(0=no display, 1=display after each iteration of the crossfold validation, 2=display weight update too)
%	NN:		The number of neural nets
%	SUBBAND:	The number of subbands
%	JOB_FOLDER:     The job folder
%
%OUTPUT
%	ACC: 		The accuracy
%	overall: 	The overall accuracy for each class and the global accuracy over all the classes
%	confusion: 	The overall confusion matrix
%

	numofsubbands=SUBBAND;
	numofimages=numOfClass*IM_PER_CLASS;
	JOB_FOLDER=[JOB_FOLDER,'/..'];
     savelabs=[];
     newsubband=[];
for i=1:10 % this loop gives 10 different training/testing
							 % combinations
    traindat=[];
    testdat=[];
    labs=[];
    telabs=[];
	
if IM_PER_CLASS/NN/10 ~= floor(IM_PER_CLASS/NN/10) %we don't sort if it is not	   
	[labels,idx]=sort(labels);					   %necessary, just to be consistent
	disp('size1:')%[debug]
	size(alldat)
	alldat=alldat(:,idx);							   %with previous results.
	disp('size2:')%[debug]
	size(alldat)
end
	
	oi=zeros(1,numofimages);
	abc=[0:10:numofimages-10]+i;
	oi(abc)=1;
	tr=find(oi==0);
	ti=find(oi==1);
	testdat=alldat(:,ti);			%*testdat has 5 pr-vectors per class
									% Each pr-vector of a given class come from
									% one of the net{n}
									
	traindat=[traindat,alldat(:,tr)];
	labs=[labs,labels(:,tr)];		% training labels
	telabs=[telabs,labels(:,ti)];	%  testing labels
    data=traindat;
    w=getWeights(data, numOfClass, labs, conf, epToQuit, margin, displayProgress-1);
    w2=0*w;
    for w2index=1:1:length(w)
    	if mod(w2index,numofsubbands)==1
    		w2(w2index)=1;	
    	end
    end		%w2 is the equivalent of a "NO-MultiResolution" classification
%load([JOB_FOLDER,'/universalW.mat']);w2=ww;
    
    data=testdat;   
    ACC{i,1}=evalACC2(data,numOfClass,telabs,w,0); %	   MR Accuracy
    ACC{i,2}=evalACC2(data,numOfClass,telabs,w2,0);%	NO-MR Accuracy
    [ACC1,newsum,confusion1{1,i}]=evalACCsave(data,numOfClass,telabs,w,0,IM_PER_CLASS);
    savelabs=[savelabs,telabs];
    newsubband=[newsubband,newsum];
    [ACC2,dummy,confusion2{1,i}]=evalACCsave(data,numOfClass,telabs,w2,0,IM_PER_CLASS);
    ACC{i,1}(numOfClass+1)=ACC1;
    ACC{i,2}(numOfClass+1)=ACC2;    
    if displayProgress
        [ACC{i,2};ACC{i,1}]
    end
weights{1}{i}=w;
weights{2}{i}=w2;
end
temp=zeros(2,numOfClass+1);
confusion{1}=zeros(size(confusion1{1}));
confusion{2}=zeros(size(confusion2{1}));
for i=1:10
    temp(1,:)=temp(1,:)+ACC{i,1};
    temp(2,:)=temp(2,:)+ACC{i,2};
    confusion{1}=confusion{1}+confusion1{i};
    confusion{2}=confusion{2}+confusion2{i};
end
confusion{1}=confusion{1}/10;
confusion{2}=confusion{2}/10;
overall=temp/10;
Y=newsubband;
labelA=savelabs;
save([JOB_FOLDER,'/GLOBAL_DATA_',feat,'.mat'],'Y','labelA','weights','confusion1','confusion2'); 
%these are all the data needed to make a forensic analysis
