function [data,labels]=texture1(imagesFolder,JOB_FOLDER,IM_PER_CLASS)

%TEXTURE1: Compute 13 Haralick textures for each image & subbands.
%	   [13x mean(horizontal\vertical adj., diagonal adj.)]
%	   It uses code provided by MurphyLab (see murphylab.web.cmu.edu)
%          	(this code is in 'lib/FeatureCode')
%
%INPUT
%	imagesFolder: the folder containing the images and subbands
%	JOB_FOLDER: the folder in which we store the output
%	IM_PER_CLASS: number of images per class
%
%OUTPUT
%	data: features stored in a cell: data{1,<class_number>}{<subband_number>,<image_number inside the class>}
%	label: an vector with size <number of original images> conataining the class number for each image
%	
%Note: to use your own features respect the I/O format to make it usable by the classifier. The name of the file will be 
%      will be the name of your feature set.
%

addpath('lib/FeatureCode');%provide the ml_features() function
addpath('lib/utils');%provide the recdir() function

images=recdir(imagesFolder,'*.tif');
simg=size(images)
for i=1:simg(2)
	fprintf('\n');
    class=ceil(i/IM_PER_CLASS);
    imind=i-IM_PER_CLASS*(class-1);
    
    for j=1:simg(1)
    	X=imread(images(j,i).name,'tiff');
    	[x11, z, x12] = ml_features1(X, [], ones(size(X)),{'har'},0,0);
    	data{1,class}{j,imind}=z;
    	fprintf('-');
    end
    
	labels(i)=class;
    fprintf([images(j,i).name,' done\n']);
    end
    
save ([JOB_FOLDER,'texture1.mat'],'data','labels');%writes out the textures
