function [data,labels]=zernike(folder,JOB_FOLDER,IM_PER_CLASS)

%ZERNIKE: Compute 49 Zernike moments for each image & subbands.
%	   [13x(horizontal\vertical adjacency) 13x(diagonal - horizontal\vertical adjacency)]
%	   It uses code provided by the LANS library (see MATLAB filecentral)
%
%INPUT
%	imagesFolder: the folder containing the images and subbands
%	JOB_FOLDER: the folder in which we store the output
%	IM_PER_CLASS: number of images per class
%
%OUTPUT
%	data: features stored in a cell: data{1,<class_number>}{<subband_number>,<image_number inside the class>}
%	label: an vector with size <number of original images> conataining the class number for each image
%	
%Note: to use your own features respect the I/O format to make it usable by the classifier. The name of the file will be 
%      will be the name of your feature set.
%
a
addpath('lib/utils');%provide the recdir() function

images=recdir(folder,'*.tif');
simg=size(images)
whos
for i=1:simg(2)
	fprintf('\n');
    class=ceil(i/IM_PER_CLASS);
    imind=i-IM_PER_CLASS*(class-1);
    
    for j=1:simg(1)
    	z= getZern(imread(images(j,i).name,'tiff'));
    	data{1,class}{j,imind}=z;
    	fprintf('-');
    end
    
	labels(i)=class;
    fprintf([images(j,i).name,' done\n']);
    end
    
save ([JOB_FOLDER,'zernike.mat'],'data','labels');%writes out the zernike moments
