function [procimage,imagemask,resimg] = ml_preprocess( image, cropimage, way, bgsub)

% [PROCIMAGE,IMAGEMASK,RESIMG] = ML_PREPROCESS( IMAGE, CROPIMAGE, WAY, BGSUB)
%
% Performs background subtraction, cropping with CROPIMAGE, and
% thresholding exactly in the said order. This is the standard
% Murphy Lab way of doing it. Note that in Michael's feature code
% the order of cropping and thesholding is reversed.
% If you have no crop image, give CROPIMAGE as [].
% PROCIMAGE is the processed image ready
% to have its features calculated by ml_features()
% IMAGEMASK is the binary mask of procimage with noise removed
% by majority filtering.
% RESIMG is the residual image left over after thresholding, i.e.
% the below-threshold image (but it is background subtracted).
% WAY determines whether preprocessing should be done Michael
% Boland way (threshold before crop), or Murphy Lab way (crop
% before threshold).
% 'ml' = Murphy Lab way
% 'mb' = Michael Boland way
% BGSUB should be 'nobgsub' if you do not want background
% subtraction, otherwise omit this argument
  
%fprintf(1,'ml_preprocess being called...\n');

if( nargin < 4)
    bgsub = 'yesbgsub';
end

switch bgsub
case 'nobgsub'
otherwise
    %%% subtract background
    image = ml_imgbgsub( image, 'common');
end

if( isempty( cropimage))
    threshcropimage = [];
else
    switch way
    case 'ml'
        %%% Crop (or mask rather)
        image( find( cropimage==0)) = 0;
        % Make sure no cropping is done later
        threshcropimage = [];
    case 'mb'
        % Make sure cropping is done later
        threshcropimage = cropimage;
    otherwise
        error('Unrecognized option for the WAY argument');
    end
end

%%% Theshold
if (max(max(image))>0)
    imagemask = ml_threshcrop(image, threshcropimage);
    if (max(max(imagemask))>0)
        procimage = roifilt2(0, image, ~imagemask);
        resimg = image;
        resimg(find(imagemask))=0;
    else
        warning('No protein fluorescence left after preprocessing');
        procimage = [];
    end
end

