function mask = ml_threshcrop(image, cropimage)
% ML_THRESHCROP generates a cropped, thresholded, cleaned  image
% ML_THRESHCROP(IMAGE, CROPIMAGE), where image is the IMAGE 
%    to be processed and CROPIMAGE is a binary mask defining
%    a region of interest.  Use CROPIMAGE=[] to process the 
%    entirety of IMAGE.  Thresholding is done BEFORE applying
%    the region of interest.  The image is cleaned using the 
%    majority operation of bwmorph.
%
% 06 Aug 98
%   - 10 Jan 1999 : renamed to reflect the order of operations
%

% Written by Michael Boland
% $Id: ml_threshcrop.m,v 1.1.1.1 2005/07/12 18:20:25 tingz Exp $

Iscaled = ml_nihscale(image) ;
Timage = ml_threshold(Iscaled) ;
Ithresh = im2bw(Iscaled, Timage) ;
mask = bwmorph(Ithresh, 'majority') ;

%
% If the crop image exists, make all pixels outside the masked area
%   equal to 0.
%
if (~isempty(cropimage))
    mask = roifilt2(0, mask, ~cropimage) ;
end

function scaledimage = ml_nihscale(image)
% ml_nihscale(image)
% scales the pixel values of an image to make it like an nih image
% with 256 grey levels
%
% W. Dirks, 1998
%

% $Id: ml_threshcrop.m,v 1.1.1.1 2005/07/12 18:20:25 tingz Exp $

s = image * 253/(max(max(image))-min(min(image)))+1;
s = s/255;

scaledimage = s;

