function rotate_images(folder,angle,random,sequence)

%ROTATE_IMAGES: rotate a dataset for a given angle, or randomly, allowing or not interpolation
%
%INPUT
%	folder: the dataset
%	angle: the angle to rotate by, or if random rotation, the upper-bound of the distribution
%	random:
%		0-> no randomness, interpolation if <angle> doesn't belong to {0, 90, 180, 270, 360, ...}
%		1-> random angle distribution with 'continuous' support (0 <angle>) with probability 1.
%		2-> random angle distribution with support {0, 90, 180, ..., <angle>}. no interpolation
%	sequence: to reuse a sequence
%
%OUTPUT
%	write the images to <folder>_some_meaningful_blurb.
%	store the rotation sequence with the images as randomSeq.mat (which is random or not...)
%	ALWAYS INSPECT randomSeq.mat and the image sto see if the result correspond to what's wante.


	angle=mod(angle,360);
	rotation=[];
	
	rand('state',sum(100*clock));
	if exist('random','var')~=1
                random=0;
        end
	destination=[folder,'_rotate',num2str(angle)];
	if random==1
		destination=[destination,'_rand'];
	elseif random==2
		destination=[destination,'_rand4'];
	end
	disp(['assume "',destination,'" as a destination folder']);

	if exist(destination,'dir')~=7
		mkdir(destination);
		disp(['"',destination,'" created']);
	end
	
	images=dir([folder,'/*.tif']);
	disp([num2str(length(images)),' TIFF images found']);
        if random==0
		rotation=ones(1,length(images)).*angle;
        end
        if exist('sequence','var')==1
                load sequence;
		disp(['using ',rotation,' as a random sequence'])
                random=0;
        end
random
	for k=1:length(images)

		x=imread([folder,'/',images(k).name],'tiff');
		if random==1
%		uniform distribution with support {0,...,angle-1}%
			rotation=[rotation,ceil(rand(1)*angle-1)];
		elseif random==2
%		uniform distribution with support {0,90,180,270}%
			rotation=[rotation,ceil(rand(1)*4-1)*90];
		end
		switch rotation(k)
			case 0
				;
			case 90
				x=x(:,end+1-(1:end))';
			case 180 
				x=x(end+1-(1:end),end+1-(1:end));
			case 270
				x=x(end+1-(1:end),:)';
			otherwise
				x=imrotate(x,rotation(k),'bicubic','crop');
		end

		imwrite(x,[destination,'/',images(k).name],'tiff');
		fprintf('>');
	end
	fprintf('\n');
	save([destination,'/randomSeq.mat'],'rotation');
	disp('Done.');
