function [MR_acc NMR_acc] = mrclass(stage,type,imagesFolder,FEATURES,shuf_file,jobfolder)

%Multiresolution classifier. Uses the open-form weighting algorithm with
%10-fold cross-validation.
%Creates a new job if stage<3, otherwise it uses the last Job folder
%created. The resumed job can be bind to any existing job by providing the last argument (see details below).

%The "important" lines of code are HIGHLIGHTED BY THIS COMMENT: "%<==" (a pointing arrow)
%The rest is mostly for folder organization, read/write operations etc...

%stage:
%       1->start with the decomposition,
%
%       2->start with the feature extraction.
%
%       3-> start with building (and training)the neural network. NB: this implies dependance with
%                           respect to the image subset.
%           Pseudo-randomness is introduced at this stage (it can be controlled using shuf_file and
%           setting the pseudo-random generator to a pre-defined state)
%
%       4->classify!
%
%
%type: 
%       name of the MR decomposition used. To get all the possible names execute 'ls modules/' in a terminal
%
%imagesFolder: 
%       useful only if stage<3. Looks into the modules/<type>/images folder for a dataset
%
%FEATURES: 
%       a cell of strings that indicate which features to use. e.g.: {'texture1'} or {'texture3','morphological'} ..etc
%
%shuf_file: 
%       the name of the file to read both the shuffling and random state from. To create a new
%       random file set shuf_file to 'shuffle' or to get the natural order use 'noshuf'.
%
%jobfolder: 
%       when resuming a job, jobfolder is a path indicating where to take the data (that was previously computed) from.
%

%SET FIRST
%NOTIFICATION='myaddress@mydomain';

%GENERAL VARIABLES----------------
NN=5;		
IM_PER_CLASS=50; %this HAS TO BE A MULTIPLE OF NN
NN_SUBBAND_FOLDER='mrTMZ';%the storage folder of the NN outputs
OFFSET=0;
EP_NN=25;	%epochs to train the NN
EP=100;		%#iterations without improvement of the weight vector
MARGIN=0.01;
SET_RAND=1;	%when possible (data available), will force the random generator
normalize=0;	%set to one to get 'real' probabilities

%--------------------------------
%CODE REPOSITORY-----------------
addpath('generic_class/features');
addpath('lib/utils');
addpath('generic_class/NN');
addpath('generic_class/classifier');
%--------------------------------
JOB_FOLDER=[];
shuf=[];
rand_state=[];
%------Processing the input------
type=trim_trail(type);
type=['modules/',type];
imagesFolder=trim_trail(imagesFolder);
addpath(type);
%--------------------------------
%init. the default 
switch nargin
	case 4
		jobfolder='';
		shuf_file='';
	case 5	
		jobfolder='';
	case 6
		JOB_FOLDER=[type,'/jobs/',jobfolder]
	otherwise
	error(['mrclass accepts 4 to 6 input args. exactly, and you submitted ',...
		num2str(nargin),' arguments.']);
end
%Create the name of the folder for this job--------
HOME_F=[type,'/jobs/',imagesFolder,'_',num2str(stage)	,'_',date];
imagesFolder=[type,'/images/',imagesFolder];
%--------------------------------------------------
begin=clock; %start the timewatch

initCommand=['mrclass(',num2str(stage),',''',type,''',''',imagesFolder,''',<FEATURES>,''',shuf_file,''',''',jobfolder,''')',10];

%>>>>>>>>>>>>>>>>>>>>>>>>>>>>><<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
%>>>>>>>>>>>>>>>>>HERE BEGIN THE 'REAL' CODE<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
%>>>>>>>>>>>>>>>>>>>>>>>>>>>>><<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<

%#########################STAGE 1###############################################
if stage<=1
	tic
	SUBBAND=decomp(imagesFolder,2); 											%<==
	save([type,'/.desc.mat'],'SUBBAND');
	disp('Decomp: ');
	toc
end
%##################END OF STAGE 1###############################################
try
	load([type,'/.desc.mat'],'SUBBAND');
catch
	try
		load([imagesFolder,'/.desc.mat'],'SUBBAND');
	catch
		simg=size(recdir(imagesFolder,'*.tif'));
		SUBBAND=simg(2)
	end
end
%#########################STAGE 2###############################################
if stage<=2

	%---FOLDER ORGANIZATION----------------
	%create the new directory
		%mind not to overwrite anything
	ap='';
	ex=exist([HOME_F,ap],'dir');
	count=1;
	while (ex==7)	%to allow multiple jobs per day
		count=count+1;
		ap=['_',int2str(count)];
		ex=exist([HOME_F,ap],'dir');

	end
	job_folder=HOME_F;
	if count>1
		job_folder=[HOME_F,'_',int2str(count)];
	end
	mkdir(job_folder);
	JOB_FOLDER=[job_folder,'/'];
	%--------------------------------
			tb=clock;
	for i=1:length(FEATURES)
		disp([date,': Computing ',FEATURES{i},]);
		tic
		eval([FEATURES{i},'(imagesFolder,JOB_FOLDER,IM_PER_CLASS)']);								%<==
		toc
	end
end
%##################END OF STAGE 2###############################################

%SOME FOLDER ORGANIZATION--------------------
if exist(JOB_FOLDER)==0
	error('Please provide a folder to work in');
end
JOB_FOLDER=trim_trail(JOB_FOLDER);
JOB_FOLDER=[JOB_FOLDER,'/'];
CLASSES=length(dir([imagesFolder,'/*.tif']))/IM_PER_CLASS
shuf=ones(CLASSES,1)*(1:IM_PER_CLASS);
%--------------------------------------
%HANDLING RANDOMNESS-------------------
disp('Setting the random generator');
clck=clock;
	rand('state', sum(100*clck));


	if exist(shuf_file)==0 && strcmp(shuf_file,'shuffle')==0
	shuf_file
		SET_RAND=0;
		warning('Using natural order and do NOT force the random generator');
		rand_state{1}=rand('state');
	else
		if strcmp(shuf_file,'shuffle')==0
			load(shuf_file,'shuf','rand_state','original_rand_features');
			disp('Shuffling matrix found. ');
			if length(original_rand_features)<length(FEATURES)
				error('Not enough random parameters found. Quitting');
			elseif  length(original_rand_features)>length(FEATURES)
				warning('Too many random parameters found. Hope you know what you are doing');
			elseif sum(strcmp(FEATURES,original_rand_features))~=length(FEATURES)
				warning('Right number of random parameters, but they were not usedon the same features. Hope you know what you are doing');
			end
			if SET_RAND==1
				disp('Will force the random generator (see source code to disable forcing)');
			else
				disp('Will NOT force the random generator (see source code to enable forcing)');
			end
		else
			shuf=[];
			for cls=1:CLASSES
				shuf=[shuf; randperm(IM_PER_CLASS)];
			end
			rand_state{1}=rand('state');
			SET_RAND=0;
		end
	end
%--------------------------------------
%#########################STAGE 3###############################################
if stage<=3

	
	%SOME FOLDER ORGANIZATION--------------------
	disp([JOB_FOLDER,NN_SUBBAND_FOLDER]);
	if exist([JOB_FOLDER,NN_SUBBAND_FOLDER])==0
		mkdir([JOB_FOLDER,NN_SUBBAND_FOLDER]);
	else
	%create the new directory
		%mind not to overwrite anything
	ap='';
	ex=exist([HOME_F,ap],'dir');
	count=1;
	while (ex==7)	%to allow multiple jobs per day
		count=count+1;
		ap=['_',int2str(count)];
		ex=exist([HOME_F,ap],'dir');

	end
	job_folder=HOME_F;
	if count>1
		job_folder=[HOME_F,'_',int2str(count)];
	end
	mkdir(job_folder);

	job_folder
	%copy the data collected at stage 2 to the new folder:
        for i=1:length(FEATURES)
                try
                        copyfile([JOB_FOLDER,FEATURES{i},'.mat'],job_folder);
                        disp(['file ',FEATURES{i},'.mat found and copied!']);
		catch
                        disp(['file ',FEATURES{i},'.mat not found']);
                end
                try
                        copyfile([JOB_FOLDER,FEATURES{i},'_test.mat'],job_folder);
                	disp(['file ',FEATURES{i},'_test.mat found and copied!']);
		catch
                        disp(['file ',FEATURES{i},'_test.mat not found',10,'The same data file will be used to pick training/testing data']);
                end
        end
	JOB_FOLDER=[job_folder,'/'];
	end
	%--------------------------------------
	for i=1:length(FEATURES)	
		disp([datestr(floor(now)),': Beginning NN computations for ',FEATURES{i},' features']);
		tic
		%runNN modifies rand('state')
		if SET_RAND==1
			rand('state',rand_state{i});
			disp('Forcing the random generator..');
		else
			rand_state{i}=rand('state');
			disp('Recording the random generator state..');
		end
		runNN([JOB_FOLDER,FEATURES{i},'.mat'], [JOB_FOLDER,NN_SUBBAND_FOLDER]...
		,NN,((i-1)*SUBBAND+OFFSET),EP_NN,shuf,rand_state{i});										%<==
		disp(['NN computations completed for ',FEATURES{i},' features']);
		toc
	end
                if SET_RAND==0
                        rand_state{length(FEATURES)+1}=rand('state');
                        disp('Recording the random generator state..');
                end
                disp('Writing out the random parameters');
                original_features=FEATURES;
		original_rand_features=FEATURES
                save([JOB_FOLDER,NN_SUBBAND_FOLDER,'/randomness.mat'],'shuf','rand_state','original_rand_features');
		save([JOB_FOLDER,'.originalFeatureSet.mat'],'original_features','SUBBAND');
end
%##################END OF STAGE 3###############################################
%#########################STAGE 4###############################################
if stage<=4 %not necessary, just easier to read
	
	if SET_RAND==1
		rand('state',rand_state{end});
		disp('Forcing the random generator..');
	end
	f1=FEATURES{1};
	if f1(1)=='[' & f1(end)==']'
		range=eval(f1);
		featClean=[num2str(length(range)),'sbd'];
		%SUBBAND=length(range);
		
	else
		load([JOB_FOLDER,'.originalFeatureSet.mat'],'original_features','SUBBAND');
		range=[];
		featClean=[];
		for i=1:length(original_features)
			if length(strmatch(original_features(i),FEATURES,'-exact'))>0
				range=[range,(1+(i-1)*SUBBAND):(i*SUBBAND)];
				featClean=[featClean,original_features{i}];
			end 
		end
	end
	[ACC,overall,confusion]=runClass([JOB_FOLDER,NN_SUBBAND_FOLDER],...
	featClean,range,EP,MARGIN,IM_PER_CLASS,normalize,NN,SUBBAND);										%<==
	save([JOB_FOLDER,'RESULTS_',featClean,'.mat'],'ACC','overall','confusion');
	MR_acc = overall(1,end);
    NMR_acc = overall(2,end);
	end

%##################END OF STAGE 4###############################################
% mail_notify(NOTIFICATION,['MR job ',JOB_FOLDER,' completed'],initCommand,['Stage: ',num2str(stage),10,'Features: ',featClean]);%REMOVE
try
	addpath('generic_class/install');
	concatResults(JOB_FOLDER);
catch
	warning('concatResults.m not found');
end
disp([10,10,'End of the multiresolution classification.'])
%--------------------------END OF FUNCTION mrclass()----------------------------
%-------------------------------------------------------------------------------

%--subroutine that trims trailing /  and leading ./ of a folder name.-----------

function folder_name=trim_trail(folder_name)
if (folder_name(end)=='/')
      folder_name=folder_name(1:end-1);
end
if (folder_name([1,2])=='./')
	      folder_name=folder_name(3:end);
end
%-------------------------------------------------------------------------------
